/** Segment Menu / Widget **/

.jeg-clearfix:before, .jeg-clearfix:after{
    content: " ";
    display: table;
    clear: both;
}

.jeg_accordion_wrapper {
    border: 1px solid #e0e0e0;
    margin: 15px 0;
    clear: both;
}

.menu-item .jeg_accordion_wrapper {
    margin: 15px 13px 0 0;
}

.menu-item .jeg-form-wrapper {
    margin-bottom: 15px;
}

.jeg_accordion_heading {
    padding: 0 36px 0 15px;
    line-height: 36px;
    border-bottom: 1px solid #e0e0e0;
    background-color: #f5f5f5;
    cursor: pointer;
    position: relative;
}

.jeg_accordion_title {
    font-weight: 500;
    font-size: 13px;
}

.jeg_accordion_button {
    font-family: FontAwesome, Helvetica, Arial, sans-serif;
    position: absolute;
    right: 0;
    width: 36px;
    top: 0;
    font-size: 14px;
    line-height: 36px;
    border-left: 1px solid #e0e0e0;
    text-align: center;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.jeg_accordion_wrapper.open > .jeg_accordion_heading .jeg_accordion_button:after,
.ui-accordion-header.ui-state-active > .jeg_accordion_button:after {
    content: "\f068";
}

.jeg_accordion_button:after {
    content: "\f067";
}

.jeg_accordion_body {
    padding: 5px 15px;
    background: #fff;
}

/** loader **/

.jeg-form-loader {
    margin: 20px 0;
    position: relative;
    font-weight: bold;
    letter-spacing: 1px;
    text-transform: uppercase;
    text-align: center;
    font-size: 12px;
}

/** field **/

.widget-wrapper {
    padding: 10px 0;
}

.widget-left > label {
    font-weight: 500;
    padding-bottom: 6px;
    display: block;
}

.widget-right > i,
.widget-wrapper-top i {
    margin-top: 5px;
    clear: both;
    display: block;
    line-height: 20px;
    color: #888;
    font-style: normal;
    font-size: 12px;
}

/** image **/

.type-image .image-content .image-wrapper {
    background: #eee;
    padding: 10px;
    text-align: center;
    margin-top: 5px;
    overflow: hidden;
}

.type-image .button-image-text {
    width: 100%;
    margin: 5px 0 !important;
}

.hide-image,
.type-image .hide-button {
    display: none;
}

.type-image .image-wrapper img {
    max-width: 100%;
}
.image-wrapper .remove {
    position: absolute;
    bottom: 0;
    right: 0;
}
.image-wrapper .remove::after {
    content: "\f00d";
    font-family: FontAwesome, Helvetica, Arial, sans-serif;
    display: block;
    background: rgba(0,0,0,.7);
    color: #fff;
    width: 25px;
    text-align: center;
    line-height: 25px;
    cursor: pointer;
}
.image-wrapper > div {
    display: flex;
    float: left;
    position: relative;
    border: none;
    margin: 0 15px 15px 0;
    max-width: 150px;
    cursor: grab;
}
.image-wrapper div.ui-sortable-helper {
    cursor: grabbing;
}

/** number **/

.type-number .wrapper {
    position: relative;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button {
    position: absolute;
    right: 0;
    color: rgba(0, 0, 0, 0.3);
    border: none;
    padding: 0 5px;
    width: 20px;
    height: calc(50% + 0.5em);
    border-radius: 0;
    -webkit-border-radius: 0;
    box-shadow: none;
    -webkit-box-shadow: none;
    background: transparent;
    background: none;
    margin: 0;
    cursor: pointer;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-up {
    top: 3px;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-down {
    top: 15px;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button > span {
    display: none;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-up::before {
    content: "\f343";
    font-family: dashicons;
}

.type-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-down::before {
    content: "\f347";
    font-family: dashicons;
}

/** text **/

.widget-wrapper input[type="text"],
.widget-wrapper textarea {
    border-color: #e0e0e0;
    padding: 6px 12px;
    min-height: 32px;
    margin: 0;
    box-shadow: none;
}

/** checkbox **/

.widget-wrapper.type-checkbox .checkbox-container {
    display: block;
    margin: 10px 0 15px;
}

.widget-wrapper.type-checkbox input[type="checkbox"] {
    display: none;
}

.widget-wrapper.type-checkbox input:checked + .switch {
    background: #d4e4ff;
}

.widget-wrapper.type-checkbox .switch {
    border: 1px solid rgba(0, 0, 0, 0.1);
    margin-top: 5px;
    display: inline-block;
    width: 35px;
    height: 12px;
    border-radius: 8px;
    background: #ebebeb;
    vertical-align: middle;
    position: relative;
    cursor: pointer;
    user-select: none;
    transition: background 350ms ease;
}

.widget-wrapper.type-checkbox input:checked + .switch::after {
    background: #5f9bff;
    transform: translate3d(100%, -50%, 0);
}

.widget-wrapper.type-checkbox .switch::after {
    background: #ccc;
    border: 1px solid rgba(0, 0, 0, 0.1);
    transform: translate3d(0, -50%, 0);
}

.widget-wrapper.type-checkbox .switch::after {
    content: "";
    display: block;
    width: 20px;
    height: 20px;
    border-radius: 50%;
    position: absolute;
    top: 50%;
    left: -3px;
    transition: all 350ms cubic-bezier(0, 0.95, 0.38, 0.98), background 150ms ease;
}

/** color **/

.widget-wrapper .jeg-color-picker {
    display: none;
}

.widget-wrapper .wp-picker-container input[type=text].wp-color-picker {
    padding: 3px 5px;
    min-height: 0;
}

.widget-wrapper .wp-picker-input-wrap .button {
    margin-left: 6px;
}

/** radio image **/

.widget-wrapper .radio-image-wrapper label .radioimage_field {
    display: none;
}

.widget-wrapper .radio-image-wrapper label {
    display: inline-block;
    margin: 3px;
    vertical-align: top;
}

.widget-wrapper .radio-image-wrapper label img {
    border-width: 1px;
    border-style: solid;
    border-color: #ddd;
    padding: 3px;
}

.widget-wrapper .radio-image-wrapper label .radioimage_field:checked ~ img {
    border-color: #278ab7;
    background-color: #278ab7;
}

/** range slider **/

.widget-wrapper input[type="range"] {
    -webkit-appearance: none;
    -webkit-transition: background 0.3s;
    -moz-transition: background 0.3s;
    transition: background 0.3s;
    background-color: rgba(0, 0, 0, 0.1);
    height: 5px;
    width: calc(100% - 100px);
    padding: 0;
}

.widget-wrapper .jeg_range_value {
    font-size: 14px;
    font-weight: 400;
    text-align: center;
    width: 49px;
    border: 1px solid #ddd;
    margin-left: 8px;
    line-height: 26px;
    display: inline-block;
}

.widget-wrapper .jeg_range_value {
    font-size: 14px;
    font-weight: 400;
}

.widget-wrapper .jeg-slider-reset {
    color: rgba(0, 0, 0, 0.2);
    float: right;
    -webkit-transition: color 0.5s ease-in;
    -moz-transition: color 0.5s ease-in;
    -ms-transition: color 0.5s ease-in;
    -o-transition: color 0.5s ease-in;
    transition: color 0.5s ease-in;
}

.widget-wrapper .jeg-slider-reset span {
    font-size: 16px;
    line-height: 30px !important;
    cursor: pointer;
}

/** icon picker **/

.btn {
    display: inline-block;
    padding: 6px 12px;
    margin-bottom: 0;
    font-size: 14px;
    font-weight: 400;
    line-height: 1.42857143;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    -ms-touch-action: manipulation;
    touch-action: manipulation;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-image: none;
    border: 1px solid transparent;
}

.btn-primary {
    color: #fff;
    background-color: #337ab7;
    border-color: #2e6da4;
}

.btn-default {
    color: #333;
    background-color: #fff;
    border-color: #d2d2d2;
}

.btn-icon {
    width: 45px;
    height: 43px;
    margin: 3px;
}

.iconpicker {
    min-width: 60px;
}

.icons-count {
    font-size: 11px;
    text-align: center;
    display: block;
    margin-top: 7px;
    color: #6f6969;
}

.caret {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: 10px;
    vertical-align: middle;
    border-top: 4px dashed;
    border-top: 4px solid\9;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent;
}

.popover.bottom {
    margin-top: 10px;
}

.popover {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 9999999;
    display: none;
    max-width: 276px;
    padding: 1px;
    font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    line-height: 1.42857143;
    text-align: left;
    text-align: start;
    text-decoration: none;
    text-shadow: none;
    text-transform: none;
    letter-spacing: normal;
    word-break: normal;
    word-spacing: normal;
    word-wrap: normal;
    white-space: normal;
    background-color: #fff;
    -webkit-background-clip: padding-box;
    background-clip: padding-box;
    border: 1px solid #ccc;
    border: 1px solid rgba(0,0,0,.15);
    -webkit-box-shadow: 0 5px 10px rgba(0,0,0,.15);
    box-shadow: 0 5px 10px rgba(0,0,0,.15);
    line-break: auto;
}

.popover.bottom > .arrow {
    top: -11px;
    left: 50%;
    margin-left: -11px;
    border-top-width: 0;
    border-bottom-color: #999;
    border-bottom-color: rgba(0,0,0,.25);
}

.popover > .arrow {
    border-width: 11px;
}

.popover > .arrow,
.popover > .arrow::after {
    position: absolute;
    display: block;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
}

.popover-content {
    padding: 16px 14px 5px;
}

.text-center {
    text-align: center;
}

.popover-content .search-control {
    width: 97% !important;
    margin: 6px 3px !important;
    border-color: #cecece;
}




.widget-alert, .jeg-alert {
    width: 100%;
    clear: both;
    color: #a94442;
    background-color: #f2dede;
    border: 1px solid #ebccd1;
    padding: 9px 13px;
    box-sizing: border-box;
    margin-top: 5px;
}
.jeg-alert p {
    margin-bottom: 0;
}
.widget-alert.alert-warning,
.jeg-alert-warning {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc;
}
.widget-alert.alert-success,
.jeg-alert-success {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6;
}
.widget-alert.alert-info,
.jeg-alert-info {
    color: #31708f;
    background-color: #d9edf7;
    border-color: #bce8f1;
}
.widget-alert strong {
    font-weight: bold;
}
.widget-alert .alert-description {
    margin-top: 5px;
    line-height: 20px;
    word-wrap: break-word;
}

.alert-element {
    width: 100%;
    clear: both;
    color: #a94442;
    background-color: #f2dede;
    border: 1px solid #ebccd1;
    padding: 9px 13px;
    box-sizing: border-box;
    margin-top: 5px;
}
.alert-element.alert-warning {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc;
}
.alert-element.alert-success {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6;
}
.alert-element.alert-info {
    color: #31708f;
    background-color: #d9edf7;
    border-color: #bce8f1;
}

.alert-element strong {
    font-weight:bold;
}

.alert-element .alert-description {
    margin-top: 5px;
}

/** elementor **/

#elementor-controls .jeg_accordion_wrapper {
    margin: 9px -10px;
    border: 1px solid #e0e0e0;
}

#elementor-controls .jeg_accordion_heading {
    background: #f5f5f5;
}

#elementor-controls .jeg_accordion_body {
    padding: 5px 15px;
}

#elementor-controls .alert-element {
    margin-top: 0 !important;
    margin-left: -10px !important;
    margin-right: -10px !important;
    width: auto !important;
    margin-bottom: 15px;
}

/** Tag & Profile */
#edittag .override-category-setting > .jeg_accordion_heading,
#your-profile .override-author-setting > .jeg_accordion_heading,
#edittag .override-tag-setting > .jeg_accordion_heading {
    background-color: #fff;
    color: #212121;
    line-height: 40px;
}

/** metabox nowrap **/

.jeg_metabox_body {
    padding: 15px;
}

.jeg_metabox_body .widget-wrapper {
    display: table;
    table-layout: fixed;
    width: 100%;
    margin-bottom: 20px;
}

.jeg_metabox_body .widget-left {
    display: table-cell;
    vertical-align: top;
    padding: .5em 1em 0 0;
    width: 36%;
}

.jeg_metabox_body .widget-right {
    display: table-cell;
    position: relative;
}

.jeg_metabox_wrapper.side .widget-left,
.jeg_metabox_wrapper.side .widget-right {
    display: block;
    padding: 0;
    width: 100%;
}

.jeg_metabox_wrapper.side .widget-left {
    margin-bottom: 5px;
}

.jeg_metabox_wrapper.side .widget-right > i {
    margin-top: 7px;
}

/** tabbed option **/
.tabbed-container {
    top: -6px;
    position: relative;
    /*margin: -18px -12px;*/
    background: #f5f5f5;
    display: flex;
}

.tabbed-container .tabbed-list {
    width: 25%;
    float: left;
    padding: 0;
    margin: 0;
    border: 0;
    border-radius: 0;
    z-index: 10;
}

.tabbed-body {
    width: 75%;
    float: left;
    background: #fff;
    margin-left: -1px;
    border-radius: 0;
    border-left: 1px solid #e0e0e0;
    padding: 5px 30px;
    min-height: 250px;
    z-index: 1;
}

.tabbed-list li {
    cursor: pointer;
    float: none;
    margin: 0!important;
    padding: 0!important;
    border-radius: 0;
    display: block;
    border: 0;
    background: #f5f5f5;
    border-right: 1px solid #e0e0e0;
    border-bottom: 1px solid #e0e0e0;
}

.tabbed-list li span {
    float: none;
    display: block;
    padding: 13px;
    font-size: 13px;
    border-left: 3px solid transparent;
    margin-left: -1px;
}

.tabbed-list li.active {
    background: #fff;
    border-right: 0;
}

.jeg_tabbed_body {
    display: none;
}

.jeg_tabbed_body.active {
    display: block;
}


/** Repeater **/
.widget-wrapper-top {
    margin-bottom: 15px;
}

.widget-wrapper-top label {
    display: block;
    font-weight: bold;
    line-height: 1.7em;
}

/* repeater style */
.jeg-repeater-wrapper {
    padding: 15px;
    border: 1px solid #e0e0e0;
}
.jeg-repeater-wrapper .repeater-fields {
    margin: 0;
}
.jeg-repeater-wrapper .repeater-row {
    border: 1px solid #e0e0e0;
    margin-bottom: 10px;
    position: relative;
}
.jeg-repeater-wrapper .repeater-row.minimized {
    background: #f5f5f5;
    padding: 0;
}
.jeg-repeater-wrapper .repeater-row-header {
    border-bottom: 1px solid #e0e0e0;
    position: relative;
    padding: 10px 15px 10px 35px;
    height: auto;
    min-height: 20px;
    line-height: 30px;
    overflow: hidden;
    word-wrap: break-word;
}
.jeg-repeater-wrapper .repeater-row-label {
    font-size: 13px;
    font-weight: 600;
    line-height: 20px;
    display: block;
    text-transform: capitalize;
    width: 90%;
    overflow: hidden;
    height: 18px;
}
.repeater-row-label:before {
    content: "\f047";
    font-family: "FontAwesome", Helvetica, Arial, sans-serif;
    position: absolute;
    left: 0;
    width: 40px;
    text-align: center;
    font-weight: normal;
    margin-right: 0.5em;
    color: #aaa;
    font-size: 14px;
    text-rendering: optimizeLegibility;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
.jeg-repeater-wrapper .repeater-row-header .dashicons {
    font-size: 18px;
    position: absolute;
    right: 12px;
    top: 2px;
    color: #a0a5aa;
}
.jeg-repeater-wrapper .repeater-minimize {
    line-height: 36px;
}
.jeg-repeater-wrapper .repeater-row-content {
    padding: 12px 15px;
    display: none;
}
.jeg-repeater-wrapper .repeater-field {
    padding: 8px 0;
    width: 100%;
    clear: both;
}
.jeg-repeater-wrapper .repeater-fields .repeater-row .repeater-field.repeater-field- {
    display: none;
}
.jeg-repeater-wrapper .repeater-fields .repeater-row label {
    margin-bottom: 12px;
    clear: both;
}
.jeg-repeater-wrapper .repeater-field .customize-control-title {
    font-weight: 500;
    padding-bottom: 6px;
    display: block;
}
.jeg-repeater-wrapper .repeater-field .customize-control-description {
    margin-top: 5px;
    clear: both;
    display: block;
    line-height: 20px;
    color: #888;
    font-style: normal;
    font-size: 12px;
    padding: 0;
}
.jeg-repeater-wrapper input[type=text],
.jeg-repeater-wrapper select {
    width: 100%;
}
.jeg-repeater-wrapper .repeater-row-remove {
    color: #a00;
}
.jeg-repeater-wrapper .repeater-add-wrapper {
    padding: 8px;
    text-align: center;
    border: 1px dashed #e0e0e0;
}
.jeg-repeater-wrapper .repeater-add-wrapper .repeater-add {
    width: 100px;
}

.jeg-repeater-wrapper .jeg-image-attachment  {
    padding: 20px 0;
    margin: 0;
}

.jeg-repeater-wrapper .jeg-image-attachment img {
    max-width: 250px;
    max-height: 500px;
}

.selectize-dropdown [data-selectable], .selectize-dropdown .optgroup-header {
    padding: 5px 8px;
}

.jeg-iconpicker-popover.show {
    display: block;
}